==> geolatte-geom-1.6.0-sources.jar: org/geolatte/geom/crs/Projection.java <==
/*
 * This file is part of the GeoLatte project.
 *
 *     GeoLatte is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU Lesser General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     GeoLatte is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public License
 *     along with GeoLatte.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Copyright (C) 2010 - 2011 and Ownership of code is shared by:
 * Qmino bvba - Romeinsestraat 18 - 3001 Heverlee  (http://www.qmino.com)
 * Geovise bvba - Generaal Eisenhowerlei 9 - 2140 Antwerpen (http://www.geovise.com)
 */

package org.geolatte.geom.crs;

/**
 * A projection from geographic coordinates to projected coordinates in a Cartesian plan.
 *
 * @author Karel Maesen, Geovise BVBA
 *         creation-date: 8/2/11
 */
public class Projection {

    public final static Projection UNKNOWN = new Projection(CrsId.UNDEFINED, "unknown");

    // To indicate a "No-op" projection which simply passes through the coordinates from source to target
    // without transform
    public final static Projection NOOP = new Projection(CrsId.UNDEFINED, "no-op");


    //TODO -- change this class to contain the CrsParameters -- and introduce superclass CrsIdentifiable

    private final CrsId crsId;
    private final String name;

    public Projection(CrsId crsId, String name) {
        this.crsId = crsId;
        this.name = name;
    }

    public CrsId getCrsId() {
        return crsId;
    }

    public String getName() {
        return name;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Projection that = (Projection) o;

        if (!crsId.equals(that.crsId)) return false;
        if (name != null ? !name.equals(that.name) : that.name != null) return false;

        return true;
    }

    @Override
    public int hashCode() {
        int result = crsId.hashCode();
        result = 31 * result + (name != null ? name.hashCode() : 0);
        return result;
    }

    @Override
    public String toString() {
        return "Projection{" +
                "SRID=" + crsId +
                ", name='" + name + '\'' +
                '}';
    }
}

==> geolatte-geom-1.9.1-sources.jar: org/geolatte/geom/crs/Projection.java <==
/*
 * This file is part of the GeoLatte project.
 *
 *     GeoLatte is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU Lesser General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     GeoLatte is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU Lesser General Public License for more details.
 *
 *     You should have received a copy of the GNU Lesser General Public License
 *     along with GeoLatte.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Copyright (C) 2010 - 2011 and Ownership of code is shared by:
 * Qmino bvba - Romeinsestraat 18 - 3001 Heverlee  (http://www.qmino.com)
 * Geovise bvba - Generaal Eisenhowerlei 9 - 2140 Antwerpen (http://www.geovise.com)
 */

package org.geolatte.geom.crs;

import java.io.Serializable;

/**
 * A projection from geographic coordinates to projected coordinates in a Cartesian plan.
 *
 * @author Karel Maesen, Geovise BVBA
 *         creation-date: 8/2/11
 */
public class Projection implements Serializable {

    private static final long serialVersionUID = 6884205871950410216L;

    public final static Projection UNKNOWN = new Projection(CrsId.UNDEFINED, "unknown");

    // To indicate a "No-op" projection which simply passes through the coordinates from source to target
    // without transform
    public final static Projection NOOP = new Projection(CrsId.UNDEFINED, "no-op");


    //TODO -- change this class to contain the CrsParameters -- and introduce superclass CrsIdentifiable

    private final CrsId crsId;
    private final String name;

    public Projection(CrsId crsId, String name) {
        this.crsId = crsId;
        this.name = name;
    }

    public CrsId getCrsId() {
        return crsId;
    }

    public String getName() {
        return name;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Projection that = (Projection) o;

        if (!crsId.equals(that.crsId)) return false;
        if (name != null ? !name.equals(that.name) : that.name != null) return false;

        return true;
    }

    @Override
    public int hashCode() {
        int result = crsId.hashCode();
        result = 31 * result + (name != null ? name.hashCode() : 0);
        return result;
    }

    @Override
    public String toString() {
        return "Projection{" +
                "SRID=" + crsId +
                ", name='" + name + '\'' +
                '}';
    }
}
